@@ -1,4 +1,4 @@
-//  
+//
 //  Copyright (c) 1994, 1995 by Mike Romberg ( romberg@fsl.noaa.gov )
 //  Copyright (c) 1995, 1996, 1997-2002 by Brian Grayson (bgrayson@netbsd.org)
 //
@@ -15,16 +15,18 @@
 #define _MeterMaker_h
 
 #include "pllist.h"
+#include "meter.h"
+#include "xosview.h"
 
-class Meter;
-class XOSView;
 
 class MeterMaker : public PLList<Meter *> {
 public:
-  MeterMaker(XOSView *xos);
-  void makeMeters(void);
+	MeterMaker(XOSView *xos);
+	void makeMeters(void);
+
 private:
-  XOSView *_xos;
+	XOSView *_xos;
 };
 
+
 #endif
