@@ -45,4 +45,13 @@
 #define USE_KVM_GETSWAPINFO 1
 #endif
 
+/* Helper defines for battery meter. */
+#define XOSVIEW_BATT_NONE         0
+#define XOSVIEW_BATT_CHARGING     1
+#define XOSVIEW_BATT_DISCHARGING  2
+#define XOSVIEW_BATT_FULL         4
+#define XOSVIEW_BATT_LOW          8
+#define XOSVIEW_BATT_CRITICAL    16
+
+
 #endif
