@@ -13,14 +13,17 @@
 //    authors for a copy.
 //
 
-#include <stdlib.h>
-#include <stdio.h>
-#include "kernel.h"
 #include "loadmeter.h"
+#include "kernel.h"
+#include <stdlib.h>
+#include <string.h>
+#include <stdio.h>
+#include <iostream>
 
 
 LoadMeter::LoadMeter( XOSView *parent )
 	: FieldMeterGraph( parent, 2, "LOAD", "PROCS/MIN", 1, 1, 0 ) {
+	total_ = -1.0;
 }
 
 LoadMeter::~LoadMeter( void ) {
