@@ -17,6 +17,7 @@
 #define _MEMMETER_H_
 
 #include "fieldmetergraph.h"
+#include "xosview.h"
 
 
 class MemMeter : public FieldMeterGraph {
@@ -32,7 +33,7 @@ protected:
 	void getmeminfo( void );
 
 private:
-	u_int64_t meminfo_[5];
+	uint64_t meminfo_[5];
 };
 
 
