@@ -7,30 +7,34 @@
 #include "MeterMaker.h"
 #include "xosview.h"
 
+#include "loadmeter.h"
 #include "cpumeter.h"
 #include "memmeter.h"
-#include "swapmeter.h"
-#include "pagemeter.h"
-#include "netmeter.h"
-#include "intmeter.h"
-#include "serialmeter.h"
-#include "loadmeter.h"
-#include "btrymeter.h"
-#include "wirelessmeter.h"
-#include <fstream>
 #include "diskmeter.h"
 #include "raidmeter.h"
+#include "swapmeter.h"
+#include "pagemeter.h"
+#include "wirelessmeter.h"
+#include "netmeter.h"
+#include "nfsmeter.h"
+#include "serialmeter.h"
+#include "intmeter.h"
+#include "intratemeter.h"
+#include "btrymeter.h"
+#if defined(__i386__) || defined(__x86_64__)
+#include "coretemp.h"
+#endif
 #include "lmstemp.h"
 #include "acpitemp.h"
-#include "coretemp.h"
-#include "nfsmeter.h"
 
+#include <string.h>
 #include <stdlib.h>
-
+#include <stdio.h>
+#include <fstream>
+#include <iostream>
 #include <sstream>
 #include <iomanip>
 
-using namespace std;
 
 MeterMaker::MeterMaker(XOSView *xos){
   _xos = xos;
@@ -71,19 +75,6 @@ void MeterMaker::makeMeters(void){
   if (_xos->isResourceTrue("disk"))
       push(new DiskMeter(_xos, atof(_xos->getResource("diskBandwidth"))));
 
-  // check for the wireless meter
-  if ( _xos->isResourceTrue("wireless") ) {
-    ifstream stats( WLFILENAME );
-    if (!stats)
-      std::cerr << "Wireless Meter needs Linux Wireless Extensions or cfg80211-"
-                << "WEXT compatibility to work." << std::endl;
-    else {
-      int count = WirelessMeter::countdevices();
-      for (int i = 0; i < count; i++)
-        push(new WirelessMeter(_xos, i, ( count == 1 ? "WLAN" : WirelessMeter::wirelessStr(i))));
-    }
-  }
-
   // check for the RAID meter
   if (_xos->isResourceTrue("RAID")){
     int RAIDCount = atoi(_xos->getResource("RAIDdevicecount"));
@@ -97,6 +88,19 @@ void MeterMaker::makeMeters(void){
   if (_xos->isResourceTrue("page"))
     push(new PageMeter(_xos, atof(_xos->getResource("pageBandwidth"))));
 
+  // check for the wireless meter
+  if ( _xos->isResourceTrue("wireless") ) {
+    std::ifstream stats( WLFILENAME );
+    if (!stats)
+      std::cerr << "Wireless Meter needs Linux Wireless Extensions or cfg80211-"
+                << "WEXT compatibility to work." << std::endl;
+    else {
+      int count = WirelessMeter::countdevices();
+      for (int i = 0; i < count; i++)
+        push(new WirelessMeter(_xos, i, ( count == 1 ? "WLAN" : WirelessMeter::wirelessStr(i))));
+    }
+  }
+
   // check for the net meter
   if (_xos->isResourceTrue("net"))
     push(new NetMeter(_xos, atof(_xos->getResource("netBandwidth"))));
@@ -145,78 +149,103 @@ void MeterMaker::makeMeters(void){
       push(new IntMeter(_xos, cpuCount-1));
   }
 
+  // check for irqrate meter
+  if (_xos->isResourceTrue("irqrate"))
+    push(new IrqRateMeter(_xos));
+
   // check for the battery meter
   if (_xos->isResourceTrue("battery") && BtryMeter::has_source())
     push(new BtryMeter(_xos));
 
-  // Check for the Intel Core temperature meter
+#if defined(__i386__) || defined(__x86_64__)
+  // Check for the CPU temperature meter
   if (_xos->isResourceTrue("coretemp")) {
-    char caption[25];
-    snprintf(caption, 25, "ACT/HIGH/%s", _xos->getResourceOrUseDefault( "coretempHighest", "100" ) );
+    char caption[32], name[8] = "CPU";
+    unsigned int coreCount, pkgCount, cpu, pkg = 0;
+    snprintf(caption, 32, "ACT(\260C)/HIGH/%s",
+             _xos->getResourceOrUseDefault( "coretempHighest", "100" ) );
     const char *displayType = _xos->getResourceOrUseDefault( "coretempDisplayType", "separate" );
-    for (uint i = 1 ; ; i++) {
-      char s[80];
-      snprintf(s, 80, "coretemp%dPackage", i);
-      const char *dummy = _xos->getResourceOrUseDefault(s, NULL);
-      if (i > 1 && ( !dummy || !*dummy ))
-        break;
-      int pkg = ( dummy ? atoi(dummy) : 0 );
-      snprintf(s, 80, "coretemp%dDisplayType", i);
-      displayType = _xos->getResourceOrUseDefault( s, displayType );
-      if (strncmp(displayType, "separate", 1) == 0) {
-        unsigned int cpuCount = CoreTemp::countCpus(pkg);
-        char name[10];
-        for (uint cpu = 0; cpu < cpuCount; cpu++) {
-          sprintf(name, "CPU%d", cpu);
+
+    pkgCount = CoreTemp::countCpus();
+    if ( strncmp(displayType, "separate", 1) == 0 ) {
+      for (pkg = 0; pkg < pkgCount; pkg++) {
+        coreCount = CoreTemp::countCores(pkg);
+        for (cpu = 0; cpu < coreCount; cpu++) {
+          if (pkgCount > 1) {
+            if (cpu == 0)  // give title only to first core of each physical cpu
+              snprintf(name, 8, "CPU%d", pkg);
+            else
+              name[0] = '\0';
+          }
+          else {
+            if (coreCount > 1)
+              snprintf(name, 8, "CPU%d", cpu);
+          }
           push(new CoreTemp(_xos, name, caption, pkg, cpu));
         }
       }
-      else if (strncmp(displayType, "average", 1) == 0)
-        push(new CoreTemp(_xos, "CPU", caption, pkg, -1));
-      else if (strncmp(displayType, "maximum", 1) == 0)
-        push(new CoreTemp(_xos, "CPU", caption, pkg, -2));
-      else {
-        std::cerr << "Unknown value of coretempDisplayType: " << displayType << std::endl;
-        std::cerr << "Supported types are: separate, average and maximum." << std::endl;
-        _xos->done(1);
-      }
+    }
+    else if ( strncmp(displayType, "average", 1) == 0 ) {
+      do {
+        if (pkgCount > 1)
+          snprintf(name, 8, "CPU%d", pkg);
+        push(new CoreTemp(_xos, name, caption, pkg, -1));
+      } while (++pkg < pkgCount);
+    }
+    else if ( strncmp(displayType, "maximum", 1) == 0 ) {
+      do {
+        if (pkgCount > 1)
+          snprintf(name, 8, "CPU%d", pkg);
+        push(new CoreTemp(_xos, name, caption, pkg, -2));
+      } while (++pkg < pkgCount);
+    }
+    else {
+      std::cerr << "Unknown value of coretempDisplayType: " << displayType << std::endl;
+      std::cerr << "Supported types are: separate, average and maximum." << std::endl;
+      _xos->done(1);
     }
   }
+#endif
 
   // check for the LmsTemp meter
   if (_xos->isResourceTrue("lmstemp")){
-    char caption[80];
-    snprintf(caption, 80, "ACT/HIGH/%s",
-      _xos->getResourceOrUseDefault("lmstempHighest", "100"));
+    char caption[16], s[16];
+    const char *tempfile, *highfile, *lowfile, *name, *label;
+    snprintf( caption, 16, "ACT/HIGH/%s",
+              _xos->getResourceOrUseDefault("lmstempHighest", "100") );
     for (int i = 1 ; ; i++) {
-      char s[20];
-      snprintf(s, 20, "lmstemp%d", i);
-      const char *tempfile = _xos->getResourceOrUseDefault(s, NULL);
+      snprintf(s, 16, "lmstemp%d", i);
+      tempfile = _xos->getResourceOrUseDefault(s, NULL);
       if (!tempfile || !*tempfile)
         break;
-      snprintf(s, 20, "lmshigh%d", i);
-      const char *highfile = _xos->getResourceOrUseDefault(s, NULL);
-      snprintf(s, 20, "lmstempLabel%d", i);
-      const char *lab = _xos->getResourceOrUseDefault(s, "TMP");
-      push(new LmsTemp(_xos, tempfile, highfile, lab, caption));
+      snprintf(s, 16, "lmshigh%d", i);
+      highfile = _xos->getResourceOrUseDefault(s, NULL);
+      snprintf(s, 16, "lmslow%d", i);
+      lowfile = _xos->getResourceOrUseDefault(s, NULL);
+      snprintf(s, 16, "lmsname%d", i);
+      name = _xos->getResourceOrUseDefault(s, NULL);
+      snprintf(s, 16, "lmstempLabel%d", i);
+      label = _xos->getResourceOrUseDefault(s, "TMP");
+      push(new LmsTemp(_xos, name, tempfile, highfile, lowfile, label, caption, i));
     }
   }
 
   // check for the ACPITemp meter
   if (_xos->isResourceTrue("acpitemp")) {
-    char caption[80];
-    snprintf(caption, 80, "ACT/HIGH/%s", _xos->getResourceOrUseDefault("acpitempHighest", "100"));
+    char caption[32];
+    snprintf(caption, 32, "ACT(\260C)/HIGH/%s",
+             _xos->getResourceOrUseDefault("acpitempHighest", "100"));
     for (int i = 1 ; ; i++) {
-      char s[20];
-      snprintf(s, 20, "acpitemp%d", i);
+      char s[16];
+      snprintf(s, 16, "acpitemp%d", i);
       const char *tempfile = _xos->getResourceOrUseDefault(s, NULL);
       if (!tempfile || !*tempfile)
         break;
-      snprintf(s, 20, "acpihigh%d", i);
+      snprintf(s, 16, "acpihigh%d", i);
       const char *highfile = _xos->getResourceOrUseDefault(s, NULL);
       if (!highfile || !*highfile)
         break;
-      snprintf(s, 20, "acpitempLabel%d", i);
+      snprintf(s, 16, "acpitempLabel%d", i);
       const char *lab = _xos->getResourceOrUseDefault(s, "TMP");
       push(new ACPITemp(_xos, tempfile, highfile, lab, caption));
     }
