@@ -8,6 +8,7 @@
 //  In order to use this new serial meter, xosview needs to be suid root.
 //
 #include "serialmeter.h"
+#include <linux/serial.h>
 #include <sys/ioctl.h>
 #include <sys/types.h>
 #include <fcntl.h>
@@ -18,32 +19,15 @@
 #include <sstream>
 #include <iomanip>
 
-// This should go away after types.h gets fixed in the kernel.
-#ifdef __alpha__
-typedef unsigned char u8;
-typedef signed short s16;
-typedef unsigned short u16;
-typedef signed int s32;
-typedef unsigned int u32;
-typedef signed long long s64;
-typedef unsigned long long u64;
-#endif
-
-#if defined(GNULIBC) || defined(__GLIBC__)
-#if !defined(__powerpc__) && !defined(__hppa__) && !defined(__mips__) && !defined(__sparc__) && !defined(__sh__) && !defined(__s390__) && !defined(__s390x__) && !defined(__m68k__) && !defined(__aarch64__) && !defined(__arm__)
+/*
+ * To fetch status information requires ioperm() and inb()
+ * otherwise these meter is largely a no-op.
+ */
+#if defined(__i386__) || defined(__ia64__) || defined(__amd64__)
 #include <sys/io.h>
-#endif
-#if !defined(__alpha__) && !defined(__sparc__) && !defined(__powerpc__) && !defined(__ia64__) && !defined(__hppa__) && !defined(__arm__) && !defined(__mips__) && !defined(__sh__) && !defined(__s390__) && !defined (__s390x__) && !defined(__m68k__) && !defined(__aarch64__)
 #include <sys/perm.h>
 #define HAVE_IOPERM
 #endif
-#else
-#if !defined(__alpha__) && !defined(__sparc__) && !defined(__powerpc__) && !defined(__ia64__) && !defined(__m68k__)
-#include <asm/io.h>
-#endif
-#endif
-#include <linux/serial.h>
-
 
 SerialMeter::SerialMeter( XOSView *parent, Device device )
   : BitMeter( parent, getTitle(device), "LSR bits(0-7), MSR bits(0-7)", 16){
@@ -77,7 +61,7 @@ bool SerialMeter::getport(unsigned short int port){
 #ifdef HAVE_IOPERM
   return ioperm(port, 1, 1) != -1;
 #else
-  return -1 != -1;
+  return false;
 #endif
 }
 
