@@ -5,14 +5,9 @@
 //
 
 #include "swapmeter.h"
-#include "xosview.h"
-#include <fstream>
-#include <sstream>
 #include <stdlib.h>
 #include <sys/sysinfo.h>
 
-static const char MEMFILENAME[] = "/proc/meminfo";
-
 
 SwapMeter::SwapMeter( XOSView *parent )
 : FieldMeterGraph( parent, 2, "SWAP", "USED/FREE" ){
