@@ -1,10 +1,11 @@
+#include "xwin.h"
+#include "Xrm.h"
 #include <X11/Xatom.h>
 #include <X11/xpm.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <unistd.h>
-#include "xwin.h"
-#include "Xrm.h"
+#include <iostream>
 
 //-----------------------------------------------------------------------------
 
@@ -367,7 +368,7 @@ const char *XWin::getResource( const char *name ){
     std::cerr << "Error:  Couldn't find '" << name << "' resource in the resource database!\n";
     exit (-1);
       /*  Some compilers aren't smart enough to know that exit() exits.  */
-    return '\0';
+    return NULL;
   }
 }
 
